module.exports = defineTest({
	description: 'Simplifies conditionals in return expression'
});
